| Title: | Interactive Document for Preprocessing the Dataset |
|---|---|
| Description: | An interactive document for preprocessing the dataset using 'rmarkdown' and 'shiny' packages. Runtime examples are provided in the package function as well as at <https://analyticmodels.shinyapps.io/PREPShiny/>. |
| Authors: | Kartikeya Bolar |
| Maintainer: | Kartikeya Bolar <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.0 |
| Built: | 2026-05-27 10:51:54 UTC |
| Source: | https://github.com/cran/PREPShiny |
PREPShiny() loads interactive user interface built using R 'shiny'.
PREPShiny()PREPShiny()
Start PREPShiny
The interactive user interface is to provide an easy way for preprocessing the dataset and downloading the preprocessed dataset.
Nothing
if(interactive()){ library(rmarkdown) PREPShiny() }if(interactive()){ library(rmarkdown) PREPShiny() }